| package |
package := Package name: 'SIXX-Core'.
package paxVersion: 0;
	basicComment: ''.


package classNames
	add: #SixxClassNotFound;
	add: #SixxConstants;
	add: #SixxReadStream;
	add: #SixxWriteStream;
	add: #SixxXmlUtil;
	yourself.

package binaryGlobalNames: (Set new
	yourself).

package globalAliases: (Set new
	yourself).

package allResourceNames: (Set new
	yourself).

package setPrerequisites: (IdentitySet new
	add: '..\Object Arts\Dolphin\Base\Dolphin';
	add: 'SIXX-Dolphin';
	add: '..\Steve Waring\Yaxo\YAXO DOM';
	yourself).

package!

"Class Definitions"!

Object subclass: #SixxConstants
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	classInstanceVariableNames: 'xmlVersion xmlEncoding sixxVersion sixxStartTag xmlDeclaration'!
Object subclass: #SixxReadStream
	instanceVariableNames: 'stream sixxElements contextDictionary position limit cachedObjects'
	classVariableNames: ''
	poolDictionaries: ''
	classInstanceVariableNames: ''!
Object subclass: #SixxWriteStream
	instanceVariableNames: 'stream contextDictionary isStartTagPut isEndTagPut'
	classVariableNames: ''
	poolDictionaries: ''
	classInstanceVariableNames: ''!
Object subclass: #SixxXmlUtil
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	classInstanceVariableNames: 'convertCharDict parserAdapter'!
Warning subclass: #SixxClassNotFound
	instanceVariableNames: 'className element context'
	classVariableNames: ''
	poolDictionaries: ''
	classInstanceVariableNames: ''!

"Global Aliases"!


"Loose Methods"!

"End of package definition"!

"Source Globals"!

"Classes"!

SixxConstants guid: (GUID fromString: '{B1C93138-8661-413D-996B-26FCD500D96F}')!
SixxConstants comment: ''!
!SixxConstants categoriesForClass!Kernel-Objects! !
!SixxConstants class methodsFor!

initialize
	xmlVersion := nil.
	xmlEncoding := nil.
	sixxVersion := nil.
	sixxStartTag := nil.
	xmlDeclaration := nil!

sixxEndTag
	^'</sixx>' copy!

sixxStartTag
	sixxStartTag isNil 
		ifTrue: [sixxStartTag := '<sixx sixx.version="' , self sixxVersion , '">'].
	^sixxStartTag!

sixxVersion
	sixxVersion isNil ifTrue: [sixxVersion := '1.0'].
	^sixxVersion!

sixxVersion: versionString
	sixxStartTag := nil.
	sixxVersion := versionString!

xmlDeclaration
	xmlDeclaration isNil 
		ifTrue: 
			[xmlDeclaration := '<?xml version="' , self xmlVersion , '" encoding="' , self xmlEncoding 
						, '"?>'].
	^xmlDeclaration!

xmlEncoding
	xmlEncoding isNil ifTrue: [xmlEncoding := 'utf-8'].
	^xmlEncoding!

xmlEncoding: encodingString
	xmlDeclaration := nil.
	xmlEncoding := encodingString!

xmlVersion
	xmlVersion isNil ifTrue: [xmlVersion := '1.0'].
	^xmlVersion!

xmlVersion: versionString
	xmlDeclaration := nil.
	xmlVersion := versionString! !
!SixxConstants class categoriesFor: #initialize!class initialization!public! !
!SixxConstants class categoriesFor: #sixxEndTag!constants!public! !
!SixxConstants class categoriesFor: #sixxStartTag!constants!public! !
!SixxConstants class categoriesFor: #sixxVersion!accessing!public! !
!SixxConstants class categoriesFor: #sixxVersion:!accessing!public! !
!SixxConstants class categoriesFor: #xmlDeclaration!constants!public! !
!SixxConstants class categoriesFor: #xmlEncoding!accessing!public! !
!SixxConstants class categoriesFor: #xmlEncoding:!accessing!public! !
!SixxConstants class categoriesFor: #xmlVersion!accessing!public! !
!SixxConstants class categoriesFor: #xmlVersion:!accessing!public! !

SixxReadStream guid: (GUID fromString: '{C1E97EA3-F909-469B-B5F3-51EB8476FFC4}')!
SixxReadStream comment: ''!
!SixxReadStream categoriesForClass!Kernel-Objects! !
!SixxReadStream methodsFor!

atEnd
	^self position >= self limit!

cachedObjects
	^cachedObjects!

checkSixxElement: sixxElement
	(SixxXmlUtil nameFrom: sixxElement) = #sixx
		ifFalse: [self error: 'unexpected element: ' , (SixxXmlUtil nameFrom: sixxElement)]!

close
	self stream close!

contents
	^(self next: self size) asArray!

contextDictionary
	^contextDictionary!

initialize
	contextDictionary := IdentityDictionary new.
	position := 0.
	sixxElements := self parseStream: stream.
	limit := sixxElements isNil ifTrue: [0] ifFalse: [sixxElements size].
	cachedObjects := Dictionary new!

limit
	^limit!

next
	^self atEnd 
		ifFalse: 
			[position := position + 1.
			self cachedObjects at: position
				ifAbsentPut: [self readSixxFromSixxElement: (sixxElements at: position)]]!

next: anInteger
	| ord |
	anInteger < 0 ifTrue: [^nil].
	ord := OrderedCollection new: anInteger.
	anInteger timesRepeat: [self atEnd ifFalse: [ord add: self next]].
	^ord!

on: aStream
	stream := aStream.
	self initialize!

parseStream: aStream
	| root |
	aStream isNil ifTrue: [^nil].
	root := SixxXmlUtil parseXml: aStream.
	self checkSixxElement: root.
	^SixxXmlUtil elementsFrom: root!

peek
	| nextObj |
	nextObj := self next.
	self privatePosition: self position - 1.
	^nextObj!

position
	^position!

position: anInteger
	(anInteger < 0 and: [anInteger > limit]) ifTrue: [self error: 'out of bounds'].
	self reset.
	self next: anInteger!

privatePosition: anInteger
	position := anInteger!

readOnlyFileNamed: fileName
	stream := SixxPortableUtil readFileStreamNamed: fileName.
	self initialize!

readSixxFromSixxElement: sixxElement
	^Object readSixxFromSixxElement: sixxElement context: self contextDictionary!

reset
	self privatePosition: 0!

sixxElements
	^sixxElements!

size
	^self limit!

skip: anInteger
	self position: self position + anInteger!

stream
	^stream! !
!SixxReadStream categoriesFor: #atEnd!public!testing! !
!SixxReadStream categoriesFor: #cachedObjects!accessing!public! !
!SixxReadStream categoriesFor: #checkSixxElement:!private! !
!SixxReadStream categoriesFor: #close!file open/close!public! !
!SixxReadStream categoriesFor: #contents!public!reading! !
!SixxReadStream categoriesFor: #contextDictionary!accessing!public! !
!SixxReadStream categoriesFor: #initialize!initializing!public! !
!SixxReadStream categoriesFor: #limit!accessing!public! !
!SixxReadStream categoriesFor: #next!public!reading! !
!SixxReadStream categoriesFor: #next:!public!reading! !
!SixxReadStream categoriesFor: #on:!initializing!public! !
!SixxReadStream categoriesFor: #parseStream:!private! !
!SixxReadStream categoriesFor: #peek!public!reading! !
!SixxReadStream categoriesFor: #position!public!reading! !
!SixxReadStream categoriesFor: #position:!public!reading! !
!SixxReadStream categoriesFor: #privatePosition:!private!private/accessing! !
!SixxReadStream categoriesFor: #readOnlyFileNamed:!initializing!public! !
!SixxReadStream categoriesFor: #readSixxFromSixxElement:!private! !
!SixxReadStream categoriesFor: #reset!public!reading! !
!SixxReadStream categoriesFor: #sixxElements!accessing!public! !
!SixxReadStream categoriesFor: #size!public!reading! !
!SixxReadStream categoriesFor: #skip:!public!reading! !
!SixxReadStream categoriesFor: #stream!accessing!public! !

!SixxReadStream class methodsFor!

new
	self error: 'Streams are created with on:'!

on: readStream
	^self basicNew on: readStream!

readOnlyFileNamed: fileName
	^self basicNew readOnlyFileNamed: fileName! !
!SixxReadStream class categoriesFor: #new!instance creation!public! !
!SixxReadStream class categoriesFor: #on:!instance creation!public! !
!SixxReadStream class categoriesFor: #readOnlyFileNamed:!instance creation!public! !

SixxWriteStream guid: (GUID fromString: '{B2FFA065-F0EE-4630-B028-452ABF496EDB}')!
SixxWriteStream comment: ''!
!SixxWriteStream categoriesForClass!Kernel-Objects! !
!SixxWriteStream methodsFor!

close
	self endTag.
	self stream close!

contextDictionary
	^contextDictionary!

contextDictionary: aValue
	contextDictionary := aValue!

cr
	self stream cr!

endTag
	(self isStartTagPut and: [self isEndTagPut not]) 
		ifTrue: 
			[self stream nextPutAll: SixxConstants sixxEndTag.
			self isEndTagPut: true]!

initialize
	contextDictionary := IdentityDictionary new.
	isStartTagPut := false.
	isEndTagPut := false!

isEndTagPut
	^isEndTagPut!

isEndTagPut: aValue
	isEndTagPut := aValue!

isStartTagPut
	^isStartTagPut!

isStartTagPut: aValue
	isStartTagPut := aValue!

newFileNamed: fileName
	stream := SixxPortableUtil writeFileStreamNamed: fileName.
	self initialize!

nextPut: anObject
	self startTag.
	anObject 
		sixxOn: self stream
		indent: 1
		context: self contextDictionary!

nextPutAll: aCollection
	aCollection do: [:obj | self nextPut: obj]!

on: aStream
	stream := aStream!

rawContents
	^self stream contents!

startTag
	self isStartTagPut 
		ifFalse: 
			[self stream nextPutAll: SixxConstants sixxStartTag.
			self isStartTagPut: true.
			self cr]!

stream
	^stream!

stream: aValue
	stream := aValue!

xmlDeclaration
	(self stream)
		nextPutAll: SixxConstants xmlDeclaration;
		cr! !
!SixxWriteStream categoriesFor: #close!file open/close!public! !
!SixxWriteStream categoriesFor: #contextDictionary!accessing!public! !
!SixxWriteStream categoriesFor: #contextDictionary:!accessing!public! !
!SixxWriteStream categoriesFor: #cr!public!writing! !
!SixxWriteStream categoriesFor: #endTag!public!writing! !
!SixxWriteStream categoriesFor: #initialize!initializing!public! !
!SixxWriteStream categoriesFor: #isEndTagPut!accessing!public! !
!SixxWriteStream categoriesFor: #isEndTagPut:!accessing!public! !
!SixxWriteStream categoriesFor: #isStartTagPut!accessing!public! !
!SixxWriteStream categoriesFor: #isStartTagPut:!accessing!public! !
!SixxWriteStream categoriesFor: #newFileNamed:!initializing!public! !
!SixxWriteStream categoriesFor: #nextPut:!public!writing! !
!SixxWriteStream categoriesFor: #nextPutAll:!public!writing! !
!SixxWriteStream categoriesFor: #on:!initializing!public! !
!SixxWriteStream categoriesFor: #rawContents!actions!public! !
!SixxWriteStream categoriesFor: #startTag!public!writing! !
!SixxWriteStream categoriesFor: #stream!accessing!public! !
!SixxWriteStream categoriesFor: #stream:!accessing!public! !
!SixxWriteStream categoriesFor: #xmlDeclaration!public!writing! !

!SixxWriteStream class methodsFor!

new
	^super new initialize!

newFileNamed: fileName
	^self new newFileNamed: fileName!

on: writeStream
	^self new on: writeStream!

onWithDeclaration: writeStream
	^(self on: writeStream) xmlDeclaration! !
!SixxWriteStream class categoriesFor: #new!instance creation!public! !
!SixxWriteStream class categoriesFor: #newFileNamed:!instance creation!public! !
!SixxWriteStream class categoriesFor: #on:!instance creation!public! !
!SixxWriteStream class categoriesFor: #onWithDeclaration:!instance creation!public! !

SixxXmlUtil guid: (GUID fromString: '{D27DD491-6B27-4732-9D8F-1C5E8F12A475}')!
SixxXmlUtil comment: ''!
!SixxXmlUtil categoriesForClass!Kernel-Objects! !
!SixxXmlUtil class methodsFor!

asXmlText: aString
	| wStr |
	wStr := WriteStream on: (String new: aString size).
	^(self writeXmlText: aString on: wStr) contents!

attributeAt: attributeName from: sixxElement
	^self parserAdapter attributeAt: attributeName from: sixxElement!

characterDataFrom: sixxElement
	^self parserAdapter characterDataFrom: sixxElement!

contentsWithXmlDeclaration: aString
	| wStr |
	wStr := WriteStream on: (String new: 1024).
	wStr nextPutAll: self xmlDeclaration.
	2 timesRepeat: 
			[wStr nextPut: Character cr.
			wStr nextPut: Character lf].
	wStr nextPutAll: aString.
	^wStr contents!

convertCharDict
	^convertCharDict!

elementsFrom: sixxElement
	"Quick hack for Dolphin YAXO "

	^(self parserAdapter elementsFrom: sixxElement) 
		select: [:each | each isKindOf: XMLElement]!

initConvertCharDict
	"SixxXmlUtil convertCharDict"

	convertCharDict := Dictionary new.
	0 to: 47 do: [:each | convertCharDict at: each put: '&#' , each printString , ';'].
	convertCharDict
		at: $& asciiValue put: '&amp;';
		at: $< asciiValue put: '&lt;';
		at: $> asciiValue put: '&gt;';
		at: $' asciiValue put: '&apos;';
		at: $" asciiValue put: '&quot;'.
	convertCharDict
		removeKey: Character space asciiValue;
		removeKey: Character tab asciiValue;
		removeKey: Character cr asciiValue;
		removeKey: Character lf asciiValue.
	convertCharDict
		removeKey: $/ asciiValue;
		removeKey: $- asciiValue;
		removeKey: $. asciiValue!

initialize
	"SixxXmlUtil initialize"

	self initConvertCharDict.
	parserAdapter := nil!

isTextFrom: sixxElement
	^self parserAdapter isTextFrom: sixxElement!

nameFrom: sixxElement
	^self parserAdapter nameFrom: sixxElement!

parserAdapter
	parserAdapter isNil ifTrue: [parserAdapter := self environment at: #SixxYaxoXmlParserAdapter].
	^parserAdapter!

parserAdapter: aSixxXmlParserAdapter
	parserAdapter := aSixxXmlParserAdapter!

parseXml: xmlStringOrStream
	^self parserAdapter parseXml: xmlStringOrStream!

writeXmlText: aString on: aWriteStream
	| cDict wStr |
	cDict := self convertCharDict.
	wStr := aWriteStream.
	aString do: 
			[:eachChar | 
			| val |
			val := eachChar asciiValue.
			val >= 127 
				ifTrue: 
					[wStr
						nextPutAll: '&#';
						nextPutAll: val asString;
						nextPut: $;]
				ifFalse: 
					[| conv |
					conv := cDict at: val ifAbsent: [].
					conv isNil ifTrue: [wStr nextPut: eachChar] ifFalse: [wStr nextPutAll: conv]]].
	^wStr! !
!SixxXmlUtil class categoriesFor: #asXmlText:!actions!public! !
!SixxXmlUtil class categoriesFor: #attributeAt:from:!aceions/parse!public! !
!SixxXmlUtil class categoriesFor: #characterDataFrom:!aceions/parse!public! !
!SixxXmlUtil class categoriesFor: #contentsWithXmlDeclaration:!actions!public! !
!SixxXmlUtil class categoriesFor: #convertCharDict!accessing!public! !
!SixxXmlUtil class categoriesFor: #elementsFrom:!aceions/parse!public! !
!SixxXmlUtil class categoriesFor: #initConvertCharDict!private!private/initialize! !
!SixxXmlUtil class categoriesFor: #initialize!class initialization!public! !
!SixxXmlUtil class categoriesFor: #isTextFrom:!aceions/parse!public! !
!SixxXmlUtil class categoriesFor: #nameFrom:!aceions/parse!public! !
!SixxXmlUtil class categoriesFor: #parserAdapter!accessing!public! !
!SixxXmlUtil class categoriesFor: #parserAdapter:!accessing!public! !
!SixxXmlUtil class categoriesFor: #parseXml:!actions!public! !
!SixxXmlUtil class categoriesFor: #writeXmlText:on:!actions!public! !

SixxClassNotFound guid: (GUID fromString: '{76FA86BB-4AE8-47BC-B99A-104171471CAD}')!
SixxClassNotFound comment: ''!
!SixxClassNotFound categoriesForClass!Kernel-Exception Handling! !
!SixxClassNotFound methodsFor!

className
	^className!

className: anObject
	className := anObject!

context
	^context!

context: anObject
	context := anObject!

defaultAction
	Transcript
		cr;
		show: '#warning# ' , self description.
	"self resume"
	^ nil!

description
	"Return a textual description of the exception."

	self className isNil 
		ifTrue: [^super description , ': ' , 'Type cannot be detected from XML'].
	^super description , ': ' , self className!

element
	^element!

element: anObject
	element := anObject! !
!SixxClassNotFound categoriesFor: #className!accessing!public! !
!SixxClassNotFound categoriesFor: #className:!accessing!public! !
!SixxClassNotFound categoriesFor: #context!accessing!public! !
!SixxClassNotFound categoriesFor: #context:!accessing!public! !
!SixxClassNotFound categoriesFor: #defaultAction!exception description!public! !
!SixxClassNotFound categoriesFor: #description!exception description!public! !
!SixxClassNotFound categoriesFor: #element!accessing!public! !
!SixxClassNotFound categoriesFor: #element:!accessing!public! !

!SixxClassNotFound class methodsFor!

signal: className element: xmlElement context: dictionary
	| inst |
	inst := self new.
	inst className: className.
	inst element: xmlElement.
	inst context: dictionary.
	^inst signal! !
!SixxClassNotFound class categoriesFor: #signal:element:context:!instance creation!public! !

"Binary Globals"!

"Resources"!

